import type { EdgeQueryResult, GraphQueryResultFromBackend, GraphQueryResultMetaFromBackend, NodeQueryResult } from 'ts-common';
import { getGraphStatistics } from './graphStatistics';

export * from './graphStatistics';

export const graphQueryBackend2graphQuery = (payload: GraphQueryResultFromBackend): GraphQueryResultMetaFromBackend => {
  const nodeIDs = new Set();
  const edgeIDs = new Set();

  // Assign ids to a hidden attribute _id to better identify them
  for (let i = 0; i < payload.nodes.length; i++) {
    payload.nodes[i]._id = payload.nodes[i]._id || (payload.nodes[i] as any).id;
    nodeIDs.add(payload.nodes[i]._id);
  }
  for (let i = 0; i < payload.edges.length; i++) {
    payload.edges[i]._id = payload.edges[i]._id || (payload.edges[i] as any).id;
    edgeIDs.add(payload.edges[i]._id);
  }

  // Only keep one node and one edge per id. This is also done in the backend, but we do it here as well to be sure.
  const nodes = [...nodeIDs].map(nodeID => payload.nodes.find(node => node._id === nodeID) as unknown as NodeQueryResult);
  const edges = [...edgeIDs].map(edgeID => payload.edges.find(edge => edge._id === edgeID) as unknown as EdgeQueryResult);

  const metaData = getGraphStatistics(payload);

  return { metaData, nodes, edges };
};
