import { describe, it, expect } from 'bun:test';
import { getAttributeType } from '../utils/getAttributeType';

// Sample values for testing
const invalidDate = '2023-13-03';
const validTime = '12:30:45';
const invalidTime = '25:61:61';
const invalidDatetime = '2023-10-03 25:61:61';
const validNumber = '123.45';
const invalidNumber = 'abc123';
const booleanTrue = true;
const booleanFalse = false;
const numberValue = 123;
const arrayValue = [1, 2, 3];
const objectValue = { key: 'value' };
const dateInstance = new Date('2023-10-03T12:30:45');

// Unit tests for getAttributeType function
describe('getAttributeType', () => {
  it('should correctly identify numbers as type "number"', () => {
    expect(getAttributeType(validNumber)).toBe('number');
    expect(getAttributeType(numberValue)).toBe('number');
  });

  it('should correctly identify strings as valid "time"', () => {
    expect(getAttributeType(validTime)).toBe('time');
  });

  it('should identify invalid datetime strings as "string"', () => {
    expect(getAttributeType(invalidDatetime)).toBe('string');
  });

  it('should identify invalid date strings as "string"', () => {
    expect(getAttributeType(invalidDate)).toBe('string');
  });

  it('should identify invalid time strings as "string"', () => {
    expect(getAttributeType(invalidTime)).toBe('string');
  });

  it('should correctly identify boolean values as type "boolean"', () => {
    expect(getAttributeType(booleanTrue)).toBe('boolean');
    expect(getAttributeType(booleanFalse)).toBe('boolean');
  });

  it('should correctly identify arrays as type "array"', () => {
    expect(getAttributeType(arrayValue)).toBe('array');
  });

  it('should correctly identify objects as type "object"', () => {
    expect(getAttributeType(objectValue)).toBe('object');
  });

  it('should correctly identify Date instances as type "datetime"', () => {
    expect(getAttributeType(dateInstance)).toBe('datetime');
  });

  it('should identify string representations of invalid numbers as "string"', () => {
    expect(getAttributeType(invalidNumber)).toBe('string');
  });

  it('should identify a regular string as type "string"', () => {
    expect(getAttributeType('random string')).toBe('string');
  });
});
